@@ -540,7 +540,7 @@ public:
     struct BlockingWorker  : public OpenGLContext::AsyncWorker
     {
         BlockingWorker (OpenGLContext::AsyncWorker::Ptr && workerToUse)
-            : originalWorker (static_cast<OpenGLContext::AsyncWorker::Ptr&&> (workerToUse))
+            : originalWorker (std::move (workerToUse))
         {}
 
         void operator() (OpenGLContext& calleeContext)
@@ -590,7 +590,7 @@ public:
         {
             if (shouldBlock)
             {
-                auto blocker = new BlockingWorker (static_cast<OpenGLContext::AsyncWorker::Ptr&&> (workerToUse));
+                auto blocker = new BlockingWorker (std::move (workerToUse));
                 OpenGLContext::AsyncWorker::Ptr worker (*blocker);
                 workQueue.add (worker);
 
@@ -601,7 +601,7 @@ public:
             }
             else
             {
-                workQueue.add (static_cast<OpenGLContext::AsyncWorker::Ptr&&> (workerToUse));
+                workQueue.add (std::move (workerToUse));
 
                 messageManagerLock.abort();
                 context.triggerRepaint();
@@ -1057,7 +1057,7 @@ size_t OpenGLContext::getImageCacheSize() const noexcept            { return ima
 void OpenGLContext::execute (OpenGLContext::AsyncWorker::Ptr workerToUse, bool shouldBlock)
 {
     if (auto* c = getCachedImage())
-        c->execute (static_cast<OpenGLContext::AsyncWorker::Ptr&&> (workerToUse), shouldBlock);
+        c->execute (std::move (workerToUse), shouldBlock);
     else
         jassertfalse; // You must have attached the context to a component
 }
